"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactNative = require("@testing-library/react-native");
var _ = _interopRequireDefault(require("."));
var _ChatConfigurations = require("../../../../context/ChatConfigurations");
var _Component = require("../../../../context/Storage/Component");
var _hooks = require("../../../../hooks");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.mock('../../../../context/ChatConfigurations');
jest.mock('../../../../context/Storage/Component');
jest.mock('../../../../hooks');
describe('Header component', () => {
  beforeAll(() => {
    _ChatConfigurations.useChatConfigurations.mockReturnValue({
      isChatOpen: true,
      toggleIsChatOpen: jest.fn(),
      botConfigs: {
        title: 'Bot title',
        colors: {
          main: '#000000'
        }
      }
    });
    _Component.useStorage.mockReturnValue({
      resetMessages: jest.fn()
    });
    _hooks.useEncryptedStorage.mockReturnValue({
      clear: jest.fn()
    });
    _hooks.useSocketActions.mockReturnValue({
      subscribe: jest.fn()
    });
  });
  afterAll(() => {
    jest.clearAllMocks();
  });
  it('renders the component with the correct title', () => {
    const {
      getByText
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    expect(getByText('Bot title')).toBeDefined();
  });
  it('calls onRestartConversation when reset icon is pressed', async () => {
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const restartConversationButton = getByTestId('restartConversation');
    _reactNative.fireEvent.press(restartConversationButton);
    expect((0, _Component.useStorage)().resetMessages).toHaveBeenCalledTimes(1);
    expect((0, _hooks.useEncryptedStorage)().clear).toHaveBeenCalledTimes(1);
    expect((0, _hooks.useSocketActions)().subscribe).toHaveBeenCalledTimes(1);
  });
  it('calls onClose when close icon is pressed', () => {
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const closeElement = getByTestId('closeChat');
    _reactNative.fireEvent.press(closeElement);
    expect((0, _ChatConfigurations.useChatConfigurations)().toggleIsChatOpen).toHaveBeenCalledTimes(1);
  });
});
//# sourceMappingURL=index.spec.js.map