"use strict";

var _react = _interopRequireDefault(require("react"));
var _reactNative = require("@testing-library/react-native");
var _ = _interopRequireDefault(require("."));
var _hooks = require("../../../../hooks");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
jest.mock('../../../../hooks', () => ({
  useSocketActions: jest.fn()
}));
describe('Input component', () => {
  beforeAll(() => {
    _hooks.useSocketActions.mockReturnValue({
      handleSubmitMessage: jest.fn()
    });
    jest.clearAllMocks();
  });
  it('renders the component with input and icons', () => {
    const {
      getByPlaceholderText,
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const inputElement = getByPlaceholderText('Digite algo ...');
    const filePickerElement = getByTestId('filePicker');
    const sendIconElement = getByTestId('sendIcon');
    expect(inputElement).toBeDefined();
    expect(filePickerElement).toBeDefined();
    expect(sendIconElement).toBeDefined();
  });
  it('handles user input correctly', () => {
    const {
      getByPlaceholderText
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const inputElement = getByPlaceholderText('Digite algo ...');
    const expectedMessage = 'test message';
    _reactNative.fireEvent.changeText(inputElement, expectedMessage);
    expect(inputElement.props.value).toBe(expectedMessage);
  });
  it('handles sending text messages correctly', () => {
    const {
      getByPlaceholderText,
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const inputElement = getByPlaceholderText('Digite algo ...');
    const sendIconElement = getByTestId('sendIcon');
    const expectedMessage = 'test message';
    _reactNative.fireEvent.changeText(inputElement, expectedMessage);
    _reactNative.fireEvent.press(sendIconElement);
    expect((0, _hooks.useSocketActions)().handleSubmitMessage).toHaveBeenCalledWith({
      from: 'user',
      message: expectedMessage,
      type: 'TEXT'
    });
    expect(inputElement.props.value).toBe('');
  });
  it('does not send empty messages', () => {
    const {
      getByTestId
    } = (0, _reactNative.render)( /*#__PURE__*/_react.default.createElement(_.default, null));
    const sendIconElement = getByTestId('sendIcon');
    _reactNative.fireEvent.press(sendIconElement);
    expect((0, _hooks.useSocketActions)().handleSubmitMessage).not.toHaveBeenCalled();
  });
});
//# sourceMappingURL=index.spec.js.map