"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.useSocket = void 0;
var _react = require("react");
var _providers = require("../providers");
var _types = require("../types");
var _Component = require("../context/Storage/Component");
var _useSocketActions = require("./useSocketActions");
var _useEncryptedStorage = require("./useEncryptedStorage");
var _utils = require("../utils");
var _global = require("../global");
const useSocket = wsUrl => {
  const isFirstRender = (0, _react.useRef)(true);
  const wsRef = (0, _react.useRef)(null);
  const [waitingToReconnect, setWaitingToReconnect] = (0, _react.useState)(false);
  const {
    subscribe
  } = (0, _useSocketActions.useSocketActions)();
  const {
    retrieve
  } = (0, _useEncryptedStorage.useEncryptedStorage)();
  const {
    addMessage
  } = (0, _Component.useStorage)();
  const onOpenCallback = async () => {
    await subscribe();
    const sessionId = await retrieve('sessionId');
    if (!_global.Global.socketId) {
      var _wsRef$current;
      (_wsRef$current = wsRef.current) === null || _wsRef$current === void 0 ? void 0 : _wsRef$current.sendMessage({
        action: 'link',
        data: {
          sessionId,
          botId: _global.Global.botId
        }
      });
    }
  };
  const onMessageCallback = msg => {
    (0, _utils.sendNotification)(msg);
    addMessage({
      ...msg,
      from: _types.From.BOT
    });
  };
  const disconnect = () => {
    var _wsRef$current2;
    (_wsRef$current2 = wsRef.current) === null || _wsRef$current2 === void 0 ? void 0 : _wsRef$current2.disconnect();
    setWaitingToReconnect(true);
  };
  (0, _react.useEffect)(() => {
    if (isFirstRender.current) {
      isFirstRender.current = false;
      return;
    }
    if (!wsRef.current) {
      wsRef.current = new _providers.ChatbotWebSocket(wsUrl);
      wsRef.current.onMessage(onMessageCallback);
      wsRef.current.onOpen(onOpenCallback);
      wsRef.current.connect();
    }
    return () => {
      var _wsRef$current3;
      (_wsRef$current3 = wsRef.current) === null || _wsRef$current3 === void 0 ? void 0 : _wsRef$current3.disconnect();
    };
  }, [isFirstRender.current, waitingToReconnect]);
  (0, _react.useEffect)(() => {
    if (isFirstRender.current) {
      isFirstRender.current = false;
      return;
    }
    (async () => {
      if (_global.Global.socketId) await subscribe();
    })();
  }, [isFirstRender.current, _global.Global.socketId]);
  return {
    disconnect
  };
};
exports.useSocket = useSocket;
//# sourceMappingURL=useSocket.js.map