import React from 'react';
import { Linking } from 'react-native';
import { render, fireEvent } from '@testing-library/react-native';
import { useChatConfigurations } from '../../../../context/ChatConfigurations';
import Footer from '.';
jest.mock('../../../../context/ChatConfigurations');
const mockBotConfig = {
  botConfigs: {
    poweredBy: 'Mock powered by',
    poweredByUrl: 'https://mock.powered.com'
  }
};
describe('Footer component', () => {
  it('renders text when poweredBy is present in botConfigs', () => {
    useChatConfigurations.mockReturnValueOnce(mockBotConfig);
    const {
      getByText
    } = render( /*#__PURE__*/React.createElement(Footer, null));
    const textElement = getByText(mockBotConfig.botConfigs.poweredBy);
    expect(textElement).toBeDefined();
  });
  it('does not render text when poweredBy is not present in botConfigs', () => {
    useChatConfigurations.mockReturnValueOnce({
      botConfigs: {}
    });
    const {
      queryByText
    } = render( /*#__PURE__*/React.createElement(Footer, null));
    const textElement = queryByText(mockBotConfig.botConfigs.poweredBy);
    expect(textElement).toBeNull();
  });
  it('calls Linking.openURL with poweredByUrl when text is pressed', () => {
    useChatConfigurations.mockReturnValueOnce(mockBotConfig);
    const {
      getByTestId
    } = render( /*#__PURE__*/React.createElement(Footer, null));
    const textElement = getByTestId('poweredBy');
    const mockOpenURL = jest.spyOn(Linking, 'openURL').mockImplementation(async () => {});
    fireEvent.press(textElement);
    expect(mockOpenURL).toHaveBeenCalledWith(mockBotConfig.botConfigs.poweredByUrl);
    mockOpenURL.mockRestore();
  });
});
//# sourceMappingURL=index.spec.js.map