import React from 'react';
import { render, fireEvent } from '@testing-library/react-native';
import Header from '.';
import { useChatConfigurations } from '../../../../context/ChatConfigurations';
import { useStorage } from '../../../../context/Storage/Component';
import { useSocketActions, useEncryptedStorage } from '../../../../hooks';
jest.mock('../../../../context/ChatConfigurations');
jest.mock('../../../../context/Storage/Component');
jest.mock('../../../../hooks');
describe('Header component', () => {
  beforeAll(() => {
    useChatConfigurations.mockReturnValue({
      isChatOpen: true,
      toggleIsChatOpen: jest.fn(),
      botConfigs: {
        title: 'Bot title',
        colors: {
          main: '#000000'
        }
      }
    });
    useStorage.mockReturnValue({
      resetMessages: jest.fn()
    });
    useEncryptedStorage.mockReturnValue({
      clear: jest.fn()
    });
    useSocketActions.mockReturnValue({
      subscribe: jest.fn()
    });
  });
  afterAll(() => {
    jest.clearAllMocks();
  });
  it('renders the component with the correct title', () => {
    const {
      getByText
    } = render( /*#__PURE__*/React.createElement(Header, null));
    expect(getByText('Bot title')).toBeDefined();
  });
  it('calls onRestartConversation when reset icon is pressed', async () => {
    const {
      getByTestId
    } = render( /*#__PURE__*/React.createElement(Header, null));
    const restartConversationButton = getByTestId('restartConversation');
    fireEvent.press(restartConversationButton);
    expect(useStorage().resetMessages).toHaveBeenCalledTimes(1);
    expect(useEncryptedStorage().clear).toHaveBeenCalledTimes(1);
    expect(useSocketActions().subscribe).toHaveBeenCalledTimes(1);
  });
  it('calls onClose when close icon is pressed', () => {
    const {
      getByTestId
    } = render( /*#__PURE__*/React.createElement(Header, null));
    const closeElement = getByTestId('closeChat');
    fireEvent.press(closeElement);
    expect(useChatConfigurations().toggleIsChatOpen).toHaveBeenCalledTimes(1);
  });
});
//# sourceMappingURL=index.spec.js.map