import React from 'react';
import { render, fireEvent } from '@testing-library/react-native';
import FilePicker from '.';
import { useSocketActions } from '../../../../../../hooks';
import DocumentPicker from 'react-native-document-picker';
jest.mock('react-native-document-picker');
jest.mock('../../../../../../hooks', () => ({
  useSocketActions: jest.fn(() => ({
    handleSubmitMessage: jest.fn()
  }))
}));
describe('FilePicker', () => {
  beforeAll(() => {
    useSocketActions.mockReturnValue({
      handleSubmitMessage: jest.fn()
    });
  });
  afterEach(() => {
    jest.resetAllMocks();
  });
  it('should call DocumentPicker and handleSubmitMessage when a document is selected', async () => {
    const document = {
      uri: 'file://path/to/file.pdf',
      type: 'application/pdf',
      name: 'file.pdf',
      size: 1024
    };
    DocumentPicker.pick.mockResolvedValueOnce([document]);
    const {
      getByTestId
    } = render( /*#__PURE__*/React.createElement(FilePicker, null));
    const filePickerButton = getByTestId('filePicker');
    await fireEvent.press(filePickerButton);
    expect(DocumentPicker.pick).toHaveBeenCalled();
    expect(useSocketActions().handleSubmitMessage).toHaveBeenCalled();
  });
});
//# sourceMappingURL=index.spec.js.map