import { Global } from '../global';
import { logger } from '../utils';
export class ChatbotWebSocket {
  ws = null;
  onMessageCallback = null;
  onOpenCallback = null;
  connectionTries = 0;
  maxConnectionTries = 3;
  constructor(url) {
    this.url = url;
  }
  onMessage(callback) {
    this.onMessageCallback = callback;
  }
  onOpen(callback) {
    this.onOpenCallback = callback;
  }
  connect() {
    if (this.connectionTries >= this.maxConnectionTries) {
      logger.log(`Maximum number of connection tries (${this.maxConnectionTries}) reached.`);
      return;
    }
    this.connectionTries++;
    this.ws = new WebSocket(this.url);
    this.ws.onopen = () => {
      this.connectionTries = 0;
      if (this.onOpenCallback) this.onOpenCallback();
    };
    this.ws.onclose = event => {
      logger.log(`Socket is closed. Reconnect will be attempted in 1 second. ${event.reason}`);
      setTimeout(() => {
        this.connect();
      }, 1000);
    };
    this.ws.onerror = err => {
      var _this$ws;
      logger.log(`Socket encountered error: ${JSON.stringify(err)}`);
      (_this$ws = this.ws) === null || _this$ws === void 0 ? void 0 : _this$ws.close();
    };
    this.ws.onmessage = event => {
      const socketAction = JSON.parse(event.data);
      if (socketAction.action === 'link') {
        var _socketAction$data;
        const socketId = ((_socketAction$data = socketAction.data) === null || _socketAction$data === void 0 ? void 0 : _socketAction$data.socketId) || null;
        Global.socketId = socketId || null;
      }
      if (socketAction.action === 'message' && this.onMessageCallback) {
        this.onMessageCallback(socketAction.data);
      }
    };
  }
  disconnect() {
    if (this.ws) {
      this.ws.close();
      this.ws = null;
    }
  }
  sendMessage(action) {
    if (this.ws) {
      this.ws.send(JSON.stringify(action));
    }
  }
}
//# sourceMappingURL=ChatbotWebsocket.js.map